@@ -2,19 +2,19 @@ from typing import Union
 
 from lamin_logger import logger
 
+from ._db import insert_if_not_exists
 from ._hub import sign_in_hub, sign_up_hub
 from ._settings_load import load_or_create_user_settings, load_user_settings
 from ._settings_save import save_user_settings
 from ._settings_store import settings_dir
 
 
-def signup(email: str, handle: str):
+def signup(email: str):
     """Sign up user."""
     user_settings = load_or_create_user_settings()
     user_settings.email = email
-    user_settings.handle = handle
     save_user_settings(user_settings)
-    password = sign_up_hub(email, handle)
+    password = sign_up_hub(email)
     if password == "handle-exists":  # handle already exists
         logger.error("The handle already exists. Please choose a different one.")
         return "handle-exists"
@@ -82,6 +82,8 @@ def login(
     )
     if response == "could-not-login":
         return response
+    elif response == "complete-signup":
+        return response
     else:
         user_id, user_handle = response
     if handle is None:
@@ -93,3 +95,24 @@ def login(
     from ._settings import settings
 
     settings._user_settings = None
+
+    # log in user into instance db
+    if settings.instance.name is not None:
+        # the above if condition is not safe enough
+        # users might delete a database but still keeping the
+        # current_instance.env settings file around
+        # hence, the if condition will pass despite the database
+        # having actually been deleted
+        # so, let's do another check
+        if settings.instance._dbconfig == "sqlite":
+            # let's check whether the sqlite file is actually available
+            if not settings.instance._sqlite_file.exists():
+                # if the file doesn't exist, there is no need to
+                # log in the user
+                # hence, simply end log in here
+                return None
+            # there is a remaining case where there could be a file that
+            # has no tables in it, we're ignoring this for now
+        insert_if_not_exists.user(
+            settings.user.email, settings.user.id, settings.user.handle
+        )
